@@ -16,6 +16,8 @@ ENV_SUBSCRIPTION = "GOOGLE_SUBSCRIPTION"
 ENV_DECODER = "GOOGLE_DECODER"
 DEFAULT_DECODER = "identity"
 
+PULL_TIMEOUT = 60
+
 
 def identity_decoder(raw):
     return raw.decode("utf-8")
@@ -78,7 +80,9 @@ class GooglePubSub(Engine):
         return cls(project_id, topic_id, subscription, decoder=decoder)
 
     def next(self):
-        response = self.subscriber.pull(self.subscription_path, max_messages=1)
+        response = self.subscriber.pull(
+            self.subscription_path, max_messages=1, timeout=PULL_TIMEOUT
+        )
         for msg in response.received_messages:
             self.current_msg = msg
             return self.decoder(msg.message.data)
